% Auto-generated chapter 34 for muslim
% Hadiths in this chapter: 92

\hadithdefcmd{muslim}{4972}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أُرْسِلُ الْكِلاَبَ الْمُعَلَّمَةَ فَيُمْسِكْنَ عَلَىَّ وَأَذْكُرُ اسْمَ اللَّهِ عَلَيْهِ فَقَالَ ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ الْمُعَلَّمَ وَذَكَرْتَ اسْمَ اللَّهِ عَلَيْهِ فَكُلْ ‏"‏ ‏.‏ قُلْتُ وَإِنْ قَتَلْنَ قَالَ ‏"‏ وَإِنْ قَتَلْنَ مَا لَمْ يَشْرَكْهَا كَلْبٌ لَيْسَ مَعَهَا ‏"‏ ‏.‏ قُلْتُ لَهُ فَإِنِّي أَرْمِي بِالْمِعْرَاضِ الصَّيْدَ فَأُصِيبُ فَقَالَ ‏"‏ إِذَا رَمَيْتَ بِالْمِعْرَاضِ فَخَزَقَ فَكُلْهُ وَإِنْ أَصَابَهُ بِعَرْضِهِ فَلاَ تَأْكُلْهُ ‏"‏ ‏.‏\hadithno{4972}\hadithtrans{Adi b. Hatim reported:I said: Messenger of Allah, I set off trained dogs and they catch for me (the game) and I recite the name of Allah over it (I slaughter the game by reciting Bismillah-i-Allah-o-Akbar), whereupon he said: When you set off your trained dogs, if you recited the name of Allah (while setting them off), then eat (the game). I said: Even if they (the trained dogs) kill that (the game)? He (the Holy Prophet) said: Even if these kill, but (on the condition) that no other dog, which you did not set off (along with your dogs), participates (in catching the game). I said to him: I throw Mi'rad, a heavy featherless blunt arrow, for hunting and killing (the game). Thereupon he said: When you throw Mi'rad, and it pierces, then eat, but if it falls flatly (and beats the game to death), then do not eat that}}
\hadithdefcmd{muslim}{4973}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ بَيَانٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ، بْنِ حَاتِمٍ قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْتُ إِنَّا قَوْمٌ نَصِيدُ بِهَذِهِ الْكِلاَبِ فَقَالَ ‏ "‏ إِذَا أَرْسَلْتَ كِلاَبَكَ الْمُعَلَّمَةَ وَذَكَرْتَ اسْمَ اللَّهِ عَلَيْهَا فَكُلْ مِمَّا أَمْسَكْنَ عَلَيْكَ وَإِنْ قَتَلْنَ إِلاَّ أَنْ يَأْكُلَ الْكَلْبُ فَإِنْ أَكَلَ فَلاَ تَأْكُلْ فَإِنِّي أَخَافُ أَنْ يَكُونَ إِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ وَإِنْ خَالَطَهَا كِلاَبٌ مِنْ غَيْرِهَا فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{4973}\hadithtrans{Adi b. Hatim reported:I asked Allah's Messenger (ﷺ) saying: We are a people who hunt with these (trained) dogs, then (what should we do)? Thereupon he (the Holy Prophet) said: When you set of your trained dogs having recited the name of Allah, then eat what these (hounds) have caught for you, even if it (the game) is killed, provided (the hunting dog) has not eaten (any part of the game). If it has eaten (the game), then you don't eat it as I fear that it might have caught for its own self. And do not eat it if other dogs have joined your trained dogs}}
\hadithdefcmd{muslim}{4974}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ، أَبِي السَّفَرِ عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمِعْرَاضِ فَقَالَ ‏"‏ إِذَا أَصَابَ بِحَدِّهِ فَكُلْ وَإِذَا أَصَابَ بِعَرْضِهِ فَقَتَلَ فَإِنَّهُ وَقِيذٌ فَلاَ تَأْكُلْ ‏"‏ ‏.‏ وَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْكَلْبِ فَقَالَ ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ وَذَكَرْتَ اسْمَ اللَّهِ فَكُلْ فَإِنْ أَكَلَ مِنْهُ فَلاَ تَأْكُلْ فَإِنَّهُ إِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ ‏"‏ ‏.‏ قُلْتُ فَإِنْ وَجَدْتُ مَعَ كَلْبِي كَلْبًا آخَرَ فَلاَ أَدْرِي أَيُّهُمَا أَخَذَهُ قَالَ ‏"‏ فَلاَ تَأْكُلْ فَإِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ وَلَمْ تُسَمِّ عَلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{4974}\hadithtrans{Adi b. Hatim reported that he asked the Messenger of Allah (ﷺ) about (hunting) with the help of an arrow having a stub end. He said:If it strikes (the game) with its point, then eat, but if it strikes flatly and it dies, that is Waqidh (beaten into death), do not eat that. I asked the Messenger of Allah (ﷺ) about (hunting with the help of) dogs, whereupon he said. When you send your dog (for hunting) reciting the name of Allah, then eat (the game), but if some part of it is eaten (by the dogs, then do not eat that, for it (your dog) has caught that (the-game) for itself. I (again) said: If I find along with my dog another dog, and do not know which of (the dogs) has caught (the game). then (what should I do)? Thereupon he ('Allah's Messenger) said: Then don't eat that, for you recited the name of Allah on your dog and not on the other one}}
\hadithdefcmd{muslim}{4975}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ وَأَخْبَرَنِي شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ، أَبِي السَّفَرِ قَالَ سَمِعْتُ الشَّعْبِيَّ، يَقُولُ سَمِعْتُ عَدِيَّ بْنَ حَاتِمٍ، يَقُولُ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمِعْرَاضِ ‏.‏ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{4975}\hadithtrans{Adi b. Hatim reported:I asked Allah's Messenger (ﷺ) about Mi'rad (i. e. hunting with the help of arrow having a stub end, and he stated the same (as we find in the previous hadith)}}
\hadithdefcmd{muslim}{4976}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ، أَبِي السَّفَرِ وَعَنْ نَاسٍ، ذَكَرَ شُعْبَةُ عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ عَدِيَّ بْنَ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمِعْرَاضِ ‏.‏ بِمِثْلِ ذَلِكَ ‏.‏\hadithno{4976}\hadithtrans{This hadith has been transmitted on the authority of 'Adi b. Hatim with a slight variation of words}}
\hadithdefcmd{muslim}{4977}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَيْدِ الْمِعْرَاضِ فَقَالَ ‏"‏ مَا أَصَابَ بِحَدِّهِ فَكُلْهُ وَمَا أَصَابَ بِعَرْضِهِ فَهُوَ وَقِيذٌ ‏"‏ ‏.‏ وَسَأَلْتُهُ عَنْ صَيْدِ الْكَلْبِ فَقَالَ ‏"‏ مَا أَمْسَكَ عَلَيْكَ وَلَمْ يَأْكُلْ مِنْهُ فَكُلْهُ فَإِنَّ ذَكَاتَهُ أَخْذُهُ فَإِنْ وَجَدْتَ عِنْدَهُ كَلْبًا آخَرَ فَخَشِيتَ أَنْ يَكُونَ أَخَذَهُ مَعَهُ وَقَدْ قَتَلَهُ فَلاَ تَأْكُلْ إِنَّمَا ذَكَرْتَ اسْمَ اللَّهِ عَلَى كَلْبِكَ وَلَمْ تَذْكُرْهُ عَلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{4977}\hadithtrans{Adi b. Hatim reported:I asked Allah's Messenger (ﷺ) about hunting the game with the help of Mi'rad, whereupon he said: If it strikes (the game) with its point, then eat it, but if it strikes flat, that is (the game is) beaten (into death), (then do not eat that) 'Adi further said: I asked him about hunting with the help of a dog, whereupon he said: If that (the dog) catches it (the game) for you and does not eat out of that, then you eat (the game) for Dhakat (slaughtering) of that is its being caught by it (by the dog). But if you find another dog besides it, and you fear that that dog (the second one) had caught it (the game) along with that (your dog) and killed it. then don't eat; for you recited the name of Allah on your dog and did not recite that on the other one (which joined your dog incidentally)}}
\hadithdefcmd{muslim}{4978}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ أَبِي، زَائِدَةَ بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4978}\hadithtrans{This hadith has been narrated on the authority of Zakariya b. Abu Za'ida with the same chain of transmitters}}
\hadithdefcmd{muslim}{4979}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ بْنِ عَبْدِ الْحَمِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، حَدَّثَنَا الشَّعْبِيُّ، قَالَ سَمِعْتُ عَدِيَّ بْنَ حَاتِمٍ، - وَكَانَ لَنَا جَارًا وَدَخِيلاً وَرَبِيطًا بِالنَّهْرَيْنِ - أَنَّهُ سَأَلَ النَّبِيَّ صلى الله عليه وسلم قَالَ أُرْسِلُ كَلْبِي فَأَجِدُ مَعَ كَلْبِي كَلْبًا قَدْ أَخَذَ لاَ أَدْرِي أَيُّهُمَا أَخَذَ ‏.‏ قَالَ ‏ "‏ فَلاَ تَأْكُلْ فَإِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ وَلَمْ تُسَمِّ عَلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{4979}\hadithtrans{Sha'bi reported:I heard Adi b. Hatim say-and he was our neighbour, and our partner and co worker at Nahrain-that he asked Allah's Apostle (may peace he upon him) saying: I let off my dog and find another dog along with my dog and that (any one of them) catches the (game), but I do not know which one had caught it, whereupon he (the Holy Prophet) said: Then don't eat that, for you recited the name of Allah while letting off your dog and did not recite on the other}}
\hadithdefcmd{muslim}{4980}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ ذَلِكَ ‏.‏\hadithno{4980}\hadithtrans{This hadith has been narrated oif the authority of 'Adi b. Hatim through another chain of transmitters}}
\hadithdefcmd{muslim}{4981}{حَدَّثَنِي الْوَلِيدُ بْنُ شُجَاعٍ السَّكُونِيُّ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَرْسَلْتَ كَلْبَكَ فَاذْكُرِ اسْمَ اللَّهِ فَإِنْ أَمْسَكَ عَلَيْكَ فَأَدْرَكْتَهُ حَيًّا فَاذْبَحْهُ وَإِنْ أَدْرَكْتَهُ قَدْ قَتَلَ وَلَمْ يَأْكُلْ مِنْهُ فَكُلْهُ وَإِنْ وَجَدْتَ مَعَ كَلْبِكَ كَلْبًا غَيْرَهُ وَقَدْ قَتَلَ فَلاَ تَأْكُلْ فَإِنَّكَ لاَ تَدْرِي أَيُّهُمَا قَتَلَهُ وَإِنْ رَمَيْتَ سَهْمَكَ فَاذْكُرِ اسْمَ اللَّهِ فَإِنْ غَابَ عَنْكَ يَوْمًا فَلَمْ تَجِدْ فِيهِ إِلاَّ أَثَرَ سَهْمِكَ فَكُلْ إِنْ شِئْتَ وَإِنْ وَجَدْتَهُ غَرِيقًا فِي الْمَاءِ فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{4981}\hadithtrans{Adi b. Hatim reported:Allah's Messenger (way peace be upon him) said to me: When you let off your dog, recite the name of Allah, and if it catches (game for you) and you find it alive, then slaughter it; if you find it killed and that (your dog) has eaten nothing out of that, (even then) you may eat it; but if you find along with your dog another dog, and (the game an) dead, then don't eat, for you do not know which of the two has killed it. And if you shoot your arrow, recite the name of Allah, but if it (game) goes out of your sight for a day and you do not find on that but the mark of your arrow, then eat that it you so like, but if you find it drowned in water, then don't eat that}}
\hadithdefcmd{muslim}{4982}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا عَاصِمٌ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّيْدِ قَالَ ‏ "‏ إِذَا رَمَيْتَ سَهْمَكَ فَاذْكُرِ اسْمَ اللَّهِ فَإِنْ وَجَدْتَهُ قَدْ قَتَلَ فَكُلْ إِلاَّ أَنْ تَجِدَهُ قَدْ وَقَعَ فِي مَاءٍ فَإِنَّكَ لاَ تَدْرِي الْمَاءُ قَتَلَهُ أَوْ سَهْمُكَ ‏"‏ ‏.‏\hadithno{4982}\hadithtrans{Adi b. Hatim reported:I asked Allah's Messenger (ﷺ) about hunting. He said: When you shoot your arrow, recite the name of Allah, and if you find it (the arrow) killed (that). then eat, except when you find it fallen into water, for in that case you do not know whether it is water that caused its death or your arrow}}
\hadithdefcmd{muslim}{4983}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، قَالَ سَمِعْتُ رَبِيعَةَ بْنَ يَزِيدَ الدِّمَشْقِيَّ، يَقُولُ أَخْبَرَنِي أَبُو إِدْرِيسَ، عَائِذُ اللَّهِ قَالَ سَمِعْتُ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ، يَقُولُ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا بِأَرْضِ قَوْمٍ مِنْ أَهْلِ الْكِتَابِ نَأْكُلُ فِي آنِيَتِهِمْ وَأَرْضِ صَيْدٍ أَصِيدُ بِقَوْسِي وَأَصِيدُ بِكَلْبِيَ الْمُعَلَّمِ أَوْ بِكَلْبِيَ الَّذِي لَيْسَ بِمُعَلَّمٍ فَأَخْبِرْنِي مَا الَّذِي يَحِلُّ لَنَا مِنْ ذَلِكَ قَالَ ‏ "‏ أَمَّا مَا ذَكَرْتَ أَنَّكُمْ بِأَرْضِ قَوْمٍ مِنْ أَهْلِ الْكِتَابِ تَأْكُلُونَ فِي آنِيَتِهِمْ فَإِنْ وَجَدْتُمْ غَيْرَ آنِيَتِهِمْ فَلاَ تَأْكُلُوا فِيهَا وَإِنْ لَمْ تَجِدُوا فَاغْسِلُوهَا ثُمَّ كُلُوا فِيهَا وَأَمَّا مَا ذَكَرْتَ أَنَّكَ بِأَرْضِ صَيْدٍ فَمَا أَصَبْتَ بِقَوْسِكَ فَاذْكُرِ اسْمَ اللَّهِ ثُمَّ كُلْ وَمَا أَصَبْتَ بِكَلْبِكَ الْمُعَلَّمِ فَاذْكُرِ اسْمَ اللَّهِ ثُمَّ كُلْ وَمَا أَصَبْتَ بِكَلْبِكَ الَّذِي لَيْسَ بِمُعَلَّمٍ فَأَدْرَكْتَ ذَكَاتَهُ فَكُلْ ‏"‏ ‏.‏\hadithno{4983}\hadithtrans{Abu Tha'laba al-Khushani reported:I came to Allah's Messenger (ﷺ) and said: Allah's Messenger, we are in the land of the People of the Book, (so) we eat in their utensils, and (live) in a hunting region. where I hunt with, the help of my bow, and hunt with my trained dog, or with my dog which is not trained. So inform me what is lawful (Halal) for us out of that. He (the Holy Prophet) said: Regarding what you have mentioned of the fact that you live in the land belonging to the People of the Book and so you eat in their utensils, but if you can get utensils other than theirs, then don't eat in them; but if you do not find any, then wash them and eat in them. And regarding what you have mentioned about (your living) in a hunting region, what you hunt, (strike) with the help of your bow, recite the name of Allah (while shooting an arrow) and then eat; and what you catch with the help of your trained dog, recite the name of Allah (while letting oil) the dog and then eat it, and what you get with the help of your untrained dog, (if you find it alive) and slaughter it (according to the law of the Shari'ah), eat it}}
\hadithdefcmd{muslim}{4984}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْمُقْرِئُ، كِلاَهُمَا عَنْ حَيْوَةَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ ابْنِ الْمُبَارَكِ غَيْرَ أَنَّ حَدِيثَ ابْنِ وَهْبٍ، لَمْ يَذْكُرْ فِيهِ صَيْدَ الْقَوْسِ ‏.‏\hadithno{4984}\hadithtrans{This hadith has been narrated on the authority of Haiwa with the same chain of transmitters, but with a slight variation of words}}
\hadithdefcmd{muslim}{4985}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا أَبُو عَبْدِ اللَّهِ، حَمَّادُ بْنُ خَالِدٍ الْخَيَّاطُ عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي ثَعْلَبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَمَيْتَ بِسَهْمِكَ فَغَابَ عَنْكَ فَأَدْرَكْتَهُ فَكُلْهُ مَا لَمْ يُنْتِنْ ‏"‏ ‏.‏\hadithno{4985}\hadithtrans{Abu Tha'laba reported Allah's Messenger (ﷺ) having said this:If you shoot with your arrow and (the game) goes out of your sight and you find it (later on), then eat that if it has not gone rotten}}
\hadithdefcmd{muslim}{4986}{وَحَدَّثَنِي مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، حَدَّثَنِي مُعَاوِيَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي ثَعْلَبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الَّذِي يُدْرِكُ صَيْدَهُ بَعْدَ ثَلاَثٍ ‏ "‏ فَكُلْهُ مَا لَمْ يُنْتِنْ ‏"‏ ‏.‏\hadithno{4986}\hadithtrans{Abu Tha'laba reported Allah's Apostle (ﷺ) as saying about one who comes three days later on the game he has shot:Eat it, provided it has not gone rotten}}
\hadithdefcmd{muslim}{4987}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنِ الْعَلاَءِ، عَنْ مَكْحُولٍ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم حَدِيثَهُ فِي الصَّيْدِ ثُمَّ قَالَ ابْنُ حَاتِمٍ حَدَّثَنَا ابْنُ مَهْدِيٍّ عَنْ مُعَاوِيَةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ وَأَبِي الزَّاهِرِيَّةِ عَنْ جُبَيْرِ بْنِ نُفَيْرٍ عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ ‏.‏ بِمِثْلِ حَدِيثِ الْعَلاَءِ غَيْرَ أَنَّهُ لَمْ يَذْكُرْ نُتُونَتَهُ وَقَالَ فِي الْكَلْبِ ‏ "‏ كُلْهُ بَعْدَ ثَلاَثٍ إِلاَّ أَنْ يُنْتِنَ فَدَعْهُ ‏"‏ ‏.‏\hadithno{4987}\hadithtrans{This hadith has been transmitted on the authority of Abu Tha'laba al- Khushani with a slight variation of (words):He (the Holy Prophet) said in regard to the game killed by (a trained) dog: Eat after three days provided it has not gone rotten}}
\hadithdefcmd{muslim}{4988}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ، عَنْ أَبِي، ثَعْلَبَةَ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السَّبُعِ ‏.‏ زَادَ إِسْحَاقُ وَابْنُ أَبِي عُمَرَ فِي حَدِيثِهِمَا قَالَ الزُّهْرِيُّ وَلَمْ نَسْمَعْ بِهَذَا حَتَّى قَدِمْنَا الشَّامَ ‏.‏\hadithno{4988}\hadithtrans{Abu Tha'laba reported that Allah's Apostle (may peace be upon prohibited the eating of every fanged beast of prey. Zuhri added:We did not bear of it until we came to Syria)}}
\hadithdefcmd{muslim}{4989}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، أَنَّهُ سَمِعَ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏ قَالَ ابْنُ شِهَابٍ وَلَمْ أَسْمَعْ ذَلِكَ مِنْ عُلَمَائِنَا بِالْحِجَازِ حَتَّى حَدَّثَنِي أَبُو إِدْرِيسَ وَكَانَ مِنْ فُقَهَاءِ أَهْلِ الشَّامِ ‏.‏\hadithno{4989}\hadithtrans{Abu Tha'laba al-Khushani reported that Allah's Messenger (ﷺ) prohibited the eating of all fanged beasts. Ibn Shihab said:I did not bear of this from our 'Ulama' in the Hijaz, until Abu Idris narrated that to me and he was one of the jurists of Syria}}
\hadithdefcmd{muslim}{4990}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، - يَعْنِي ابْنَ الْحَارِثِ - أَنَّ ابْنَ شِهَابٍ، حَدَّثَهُ عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّالله عليه وسلم نَهَى عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏\hadithno{4990}\hadithtrans{Abu Tha'laba al-Khushani reported Allah's Messenger (ﷺ) having prohibited the eating of all fanged beasts of prey}}
\hadithdefcmd{muslim}{4991}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، وَابْنُ أَبِي ذِئْبٍ، وَعَمْرُو بْنُ الْحَارِثِ وَيُونُسُ بْنُ يَزِيدَ وَغَيْرُهُمْ ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ عَبْدِ الرَّزَّاقِ، عَنْ مَعْمَرٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يُوسُفُ بْنُ الْمَاجِشُونِ، ح وَحَدَّثَنَا الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ يُونُسَ وَعَمْرٍو كُلُّهُمْ ذَكَرَ الأَكْلَ إِلاَّ صَالِحًا وَيُوسُفَ فَإِنَّ حَدِيثَهُمَا نَهَى عَنْ كُلِّ ذِي نَابٍ مِنَ السَّبُعِ ‏.‏\hadithno{4991}\hadithtrans{This hadith has been narrated through several other chains of transmitters, but some of the chains have a slight variation of words}}
\hadithdefcmd{muslim}{4992}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - عَنْ مَالِكٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، عَنْ عَبِيدَةَ بْنِ سُفْيَانَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ ذِي نَابٍ مِنَ السِّبَاعِ فَأَكْلُهُ حَرَامٌ ‏"‏ ‏.‏\hadithno{4992}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The eating of all fanged beasts of prey is unlawful}}
\hadithdefcmd{muslim}{4993}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4993}\hadithtrans{This hadith has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{4994}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مَيْمُونِ، بْنِ مِهْرَانَ عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ وَعَنْ كُلِّ ذِي مِخْلَبٍ مِنَ الطَّيْرِ ‏.‏\hadithno{4994}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) prohibited the eating of all fanged beasts of prey, and all the birds having talons}}
\hadithdefcmd{muslim}{4995}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا سَهْلُ بْنُ حَمَّادٍ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4995}\hadithtrans{This hadith has been transmitted on the authority of Shu'ba}}
\hadithdefcmd{muslim}{4996}{وَحَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا الْحَكَمُ، وَأَبُو بِشْرٍ عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ وَعَنْ كُلِّ ذِي مِخْلَبٍ مِنَ الطَّيْرِ ‏.‏\hadithno{4996}\hadithtrans{Ibn Abbas reported that Allah's Messenger (ﷺ) forbade (the eating) of all the fanged beasts of prey, and of all the birds having talons}}
\hadithdefcmd{muslim}{4997}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، قَالَ أَبُو بِشْرٍ أَخْبَرَنَا عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى ح وَحَدَّثَنِي أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ شُعْبَةَ عَنِ الْحَكَمِ ‏.‏\hadithno{4997}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Abbas through a different chain of transmitters}}
\hadithdefcmd{muslim}{4998}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، ح وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَمَّرَ عَلَيْنَا أَبَا عُبَيْدَةَ نَتَلَقَّى عِيرًا لِقُرَيْشٍ وَزَوَّدَنَا جِرَابًا مِنْ تَمْرٍ لَمْ يَجِدْ لَنَا غَيْرَهُ فَكَانَ أَبُو عُبَيْدَةَ يُعْطِينَا تَمْرَةً تَمْرَةً - قَالَ - فَقُلْتُ كَيْفَ كُنْتُمْ تَصْنَعُونَ بِهَا قَالَ نَمَصُّهَا كَمَا يَمَصُّ الصَّبِيُّ ثُمَّ نَشْرَبُ عَلَيْهَا مِنَ الْمَاءِ فَتَكْفِينَا يَوْمَنَا إِلَى اللَّيْلِ وَكُنَّا نَضْرِبُ بِعِصِيِّنَا الْخَبَطَ ثُمَّ نَبُلُّهُ بِالْمَاءِ فَنَأْكُلُهُ قَالَ وَانْطَلَقْنَا عَلَى سَاحِلِ الْبَحْرِ فَرُفِعَ لَنَا عَلَى سَاحِلِ الْبَحْرِ كَهَيْئَةِ الْكَثِيبِ الضَّخْمِ فَأَتَيْنَاهُ فَإِذَا هِيَ دَابَّةٌ تُدْعَى الْعَنْبَرَ قَالَ قَالَ أَبُو عُبَيْدَةَ مَيْتَةٌ ثُمَّ قَالَ لاَ بَلْ نَحْنُ رُسُلُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي سَبِيلِ اللَّهِ وَقَدِ اضْطُرِرْتُمْ فَكُلُوا قَالَ فَأَقَمْنَا عَلَيْهِ شَهْرًا وَنَحْنُ ثَلاَثُ مِائَةٍ حَتَّى سَمِنَّا قَالَ وَلَقَدْ رَأَيْتُنَا نَغْتَرِفُ مِنْ وَقْبِ عَيْنِهِ بِالْقِلاَلِ الدُّهْنَ وَنَقْتَطِعُ مِنْهُ الْفِدَرَ كَالثَّوْرِ - أَوْ كَقَدْرِ الثَّوْرِ - فَلَقَدْ أَخَذَ مِنَّا أَبُو عُبَيْدَةَ ثَلاَثَةَ عَشَرَ رَجُلاً فَأَقْعَدَهُمْ فِي وَقْبِ عَيْنِهِ وَأَخَذَ ضِلَعًا مِنْ أَضْلاَعِهِ فَأَقَامَهَا ثُمَّ رَحَلَ أَعْظَمَ بَعِيرٍ مَعَنَا فَمَرَّ مِنْ تَحْتِهَا وَتَزَوَّدْنَا مِنْ لَحْمِهِ وَشَائِقَ فَلَمَّا قَدِمْنَا الْمَدِينَةَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرْنَا ذَلِكَ لَهُ فَقَالَ ‏ "‏ هُوَ رِزْقٌ أَخْرَجَهُ اللَّهُ لَكُمْ فَهَلْ مَعَكُمْ مِنْ لَحْمِهِ شَىْءٌ فَتُطْعِمُونَا ‏"‏ ‏.‏ قَالَ فَأَرْسَلْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْهُ فَأَكَلَهُ ‏.‏\hadithno{4998}\hadithtrans{Jabir reported:Allah's Messenger (may peace he upon him) sent us (on an expedition) and appointed Abu 'Ubaida our chief that we might intercept a caravan of the Quraish and provided us with a bag of dates. And he found for us nothing besides it. Abu Ubaida gave each of us one date (everyday). I (Abu Zubair, one of the narrators) said: What did you do with that? He said: We sucked that just as a baby sucks and then drank water over that, and it sufficed us for the day until night. We beat off leaves with the help of our staffs, then drenched them with water and ate them. We then went to the coast of the sea, and there rose before us on the coast of the sea something like a big mound. We came near that and we found that it was a beast, called al-'Anbar (spermaceti whale). Abu 'Ubaida said. It is dead. He then said: No (but it does not matter), we have been sent by the Messenger of Allah (ﷺ) in the path of Allah and you are hard pressed (on account of the scarcity of food), so you eat that. We three hundred in number stayed there for a month, until we grew bulky. He (Jabir) said: I saw how we extracted pitcher after pitcher full of fat from the cavity of its eye, and sliced from it compact piece of meat equal to a bull or like a bull. Abu 'Ubaida called forth thirteen men from us and he made them sit in the cavity of its eye, and he took hold of one of the ribs of its chest and made it stand and then saddled the biggest of the camels we had with us and it passed under it (the arched rib), and we provided ourselves with pieces of boiled meat (especially for use in our journey). When we came back to Medina, we went to Allah's Messenger (ﷺ) and made a mention of that to him, whereupon he said: That was a provision which Allah had brought forth for you. Is there any piece of meat (left) with you, so tnat you give to us that? He (Jabir) said: We sent to Allah's Messenger (ﷺ) tome of that (a piece of meat) and he ate it}}
\hadithdefcmd{muslim}{4999}{حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعَ عَمْرٌو، جَابِرَ بْنَ عَبْدِ اللَّهِ يَقُولُ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ ثَلاَثُمِائَةِ رَاكِبٍ وَأَمِيرُنَا أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ نَرْصُدُ عِيرًا لِقُرَيْشٍ فَأَقَمْنَا بِالسَّاحِلِ نِصْفَ شَهْرٍ فَأَصَابَنَا جُوعٌ شَدِيدٌ حَتَّى أَكَلْنَا الْخَبَطَ فَسُمِّيَ جَيْشَ الْخَبَطِ فَأَلْقَى لَنَا الْبَحْرُ دَابَّةً يُقَالُ لَهَا الْعَنْبَرُ فَأَكَلْنَا مِنْهَا نِصْفَ شَهْرٍ وَادَّهَنَّا مِنْ وَدَكِهَا حَتَّى ثَابَتْ أَجْسَامُنَا - قَالَ - فَأَخَذَ أَبُو عُبَيْدَةَ ضِلَعًا مِنْ أَضْلاَعِهِ فَنَصَبَهُ ثُمَّ نَظَرَ إِلَى أَطْوَلِ رَجُلٍ فِي الْجَيْشِ وَأَطْوَلِ جَمَلٍ فَحَمَلَهُ عَلَيْهِ فَمَرَّ تَحْتَهُ قَالَ وَجَلَسَ فِي حَجَاجِ عَيْنِهِ نَفَرٌ قَالَ وَأَخْرَجْنَا مِنْ وَقْبِ عَيْنِهِ كَذَا وَكَذَا قُلَّةَ وَدَكٍ - قَالَ - وَكَانَ مَعَنَا جِرَابٌ مِنْ تَمْرٍ فَكَانَ أَبُو عُبَيْدَةَ يُعْطِي كُلَّ رَجُلٍ مِنَّا قَبْضَةً قَبْضَةً ثُمَّ أَعْطَانَا تَمْرَةً تَمْرَةً فَلَمَّا فَنِيَ وَجَدْنَا فَقْدَهُ ‏.‏\hadithno{4999}\hadithtrans{Jabir b. 'Abdullah reported:Allah's Messenger (may peace he upon him) sent us (on an expedition). We were three hundred riders and our chief (leader) was 'Ubaida b. al-Jarrah. We were on the look out for a caravan of the Quraish. So we stayed on the coast for half a month, and were so much afflicted by extreme hunger that we (were obliged) to eat leaves. That is why it was called the Detachment of the Leaves. The ocean cast out for us an animal which was called al-'Anbar (whale). We ate of that for half of the month and rubbed its fat on our (bodies) until our bodies became stout. Abu 'Ubaida caught hold of one of its ribs and fixed that up. He then cast a glance at the tallest man of the army and the highest of the camels. and then made him ride over that, and that-tnan passed beneath it (the rib), and many a man could sit in its eye-socket, and we extracted many pitchers of fat from the cavity of its eye. We had small bags containing dates with us (before finding the whale). 'Ubaida gave every person amongst us a handful of dates (and when the provision ran short), he then gave each one of us one date. And when that (stock) was exhausted, we felt its loss}}
\hadithdefcmd{muslim}{5000}{وَحَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعَ عَمْرٌو، جَابِرًا يَقُولُ فِي جَيْشِ الْخَبَطِ إِنَّ رَجُلاً نَحَرَ ثَلاَثَ جَزَائِرَ ثُمَّ ثَلاَثًا ثُمَّ ثَلاَثًا ثُمَّ نَهَاهُ أَبُو عُبَيْدَةَ ‏.‏\hadithno{5000}\hadithtrans{Amr reported on the authority of Jabir that in the expedition of Khabat (leaves) a person slaughtered three camels, then three, then three, then Abu 'Ubaida forbade him (to do so fearing that the rides may become short)}}
\hadithdefcmd{muslim}{5001}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، - يَعْنِي ابْنَ سُلَيْمَانَ - عَنْ هِشَامِ، بْنِ عُرْوَةَ عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَعَثَنَا النَّبِيُّ صلى الله عليه وسلم وَنَحْنُ ثَلاَثُمِائَةٍ نَحْمِلُ أَزْوَادَنَا عَلَى رِقَابِنَا ‏.‏\hadithno{5001}\hadithtrans{Jabir b. 'Abdullah reported:Allah's Apostle (ﷺ) sent us (on an expedition), and we were three hundred in number, and we were carrying our bags of provisions around our necks}}
\hadithdefcmd{muslim}{5002}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي نُعَيْمٍ، وَهْبِ بْنِ كَيْسَانَ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً ثَلاَثَمِائَةٍ وَأَمَّرَ عَلَيْهِمْ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ فَفَنِيَ زَادُهُمْ فَجَمَعَ أَبُو عُبَيْدَةَ زَادَهُمْ فِي مِزْوَدٍ فَكَانَ يُقَوِّتُنَا حَتَّى كَانَ يُصِيبُنَا كُلَّ يَوْمٍ تَمْرَةٌ ‏.‏\hadithno{5002}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Messenger (ﷺ) sent on in expedition a detachment consisting of three hundred (persons) and appointed Abu 'Ubaida b. Jarrah as their chief. Their provisions ran short:'Abu 'Ubaida collected their provisions in the provision bag. and he fed us (for some time). Later on when the provisions ran short he gave us one date every day}}
\hadithdefcmd{muslim}{5003}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا الْوَلِيدُ، - يَعْنِي ابْنَ كَثِيرٍ - قَالَ سَمِعْتُ وَهْبَ بْنَ كَيْسَانَ، يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً أَنَا فِيهِمْ إِلَى سِيفِ الْبَحْرِ ‏.‏ وَسَاقُوا جَمِيعًا بَقِيَّةَ الْحَدِيثِ كَنَحْوِ حَدِيثِ عَمْرِو بْنِ دِينَارٍ وَأَبِي الزُّبَيْرِ غَيْرَ أَنَّ فِي حَدِيثِ وَهْبِ بْنِ كَيْسَانَ فَأَكَلَ مِنْهَا الْجَيْشُ ثَمَانِيَ عَشْرَةَ لَيْلَةً ‏.‏\hadithno{5003}\hadithtrans{Jabir b. Abdullah reported that Allah's Messenger (ﷺ) sent an expedition to the sea coast and I was one among them. The rest of the hadith is the same with a slight variation of wording that in the hadith transmitted on the authority of Wahb b. Kaisan (the words are):" The army ate out of that (the whale) for eighteen days}}
\hadithdefcmd{muslim}{5004}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو الْمُنْذِرِ الْقَزَّازُ، كِلاَهُمَا عَنْ دَاوُدَ بْنِ قَيْسٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، عَنْ جَابِرِ بْنِ، عَبْدِ اللَّهِ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْثًا إِلَى أَرْضِ جُهَيْنَةَ وَاسْتَعْمَلَ عَلَيْهِمْ رَجُلاً وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{5004}\hadithtrans{Jabir b. Abdullah reported that Allah's Messenger (ﷺ) sent an expedition to the land of the tribe of Juhaina, and appointed a person as a chief over them}}
\hadithdefcmd{muslim}{5005}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ، اللَّهِ وَالْحَسَنِ ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِمَا، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ مُتْعَةِ النِّسَاءِ يَوْمَ خَيْبَرَ وَعَنْ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ ‏.‏\hadithno{5005}\hadithtrans{Ali b. Abi Talib reported that Allah's Messenger (ﷺ) forbade on the Day of Khaibar temporary marriage (Muta') with women and the eating of the flesh of domestic asses}}
\hadithdefcmd{muslim}{5006}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا إِسْحَاقُ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ يُونُسَ وَعَنْ أَكْلِ، لُحُومِ الْحُمُرِ الإِنْسِيَّةِ ‏.‏\hadithno{5006}\hadithtrans{This hadith has been narrated on the authority of Zuhri through a different chain of transmitters with a slight variation of wording}}
\hadithdefcmd{muslim}{5007}{وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيِّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، كِلاَهُمَا عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ، بْنِ سَعْدٍ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا إِدْرِيسَ، أَخْبَرَهُ أَنَّ أَبَا ثَعْلَبَةَ قَالَ حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لُحُومَ الْحُمُرِ الأَهْلِيَّةِ ‏.‏\hadithno{5007}\hadithtrans{Abu Tha'laba reported that Allah's Messenger (ﷺ) prohibited (the eating) of the flesh of domestic asses}}
\hadithdefcmd{muslim}{5008}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنِي نَافِعٌ، وَسَالِمٌ عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ ‏.‏\hadithno{5008}\hadithtrans{Ibn Umar reported that Allah's Messenger (way peace be upon him) forbade the eating of the flesh of domestic asses}}
\hadithdefcmd{muslim}{5009}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي نَافِعٌ، قَالَ قَالَ ابْنُ عُمَرَ ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا أَبِي وَمَعْنُ بْنُ عِيسَى، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ الْحِمَارِ الأَهْلِيِّ يَوْمَ خَيْبَرَ وَكَانَ النَّاسُ احْتَاجُوا إِلَيْهَا ‏.‏\hadithno{5009}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (ﷺ) forbade the eating of the (flesh) of domestic asses on the Day of Khaibar in spite of the fact that people needed that}}
\hadithdefcmd{muslim}{5010}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ، فَقَالَ أَصَابَتْنَا مَجَاعَةٌ يَوْمَ خَيْبَرَ وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ أَصَبْنَا لِلْقَوْمِ حُمُرًا خَارِجَةً مِنَ الْمَدِينَةِ فَنَحَرْنَاهَا فَإِنَّ قُدُورَنَا لَتَغْلِي إِذْ نَادَى مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِ اكْفَئُوا الْقُدُورَ وَلاَ تَطْعَمُوا مِنْ لُحُومِ الْحُمُرِ شَيْئًا فَقُلْتُ حَرَّمَهَا تَحْرِيمَ مَاذَا قَالَ تَحَدَّثْنَا بَيْنَنَا فَقُلْنَا حَرَّمَهَا أَلْبَتَّةَ وَحَرَّمَهَا مِنْ أَجْلِ أَنَّهَا لَمْ تُخَمَّسْ ‏.‏\hadithno{5010}\hadithtrans{Shaibani reported:I asked 'Abdullah b. Abu Aufa about (the lawfulness or unlawfulness of) the flesh of the domestic asses. He said: We experienced hunger on the Day of Khaibar as we were with the Messenger of Allah (ﷺ). We found domestic asses in the exterior of Medina. We slaughtered them and our earthen pots were boiling when the announcer of the Messenger of Allah (ﷺ) made an announcement that the earthen pots should be turned upside down and nothing of the flesh of the domestic asses should be eaten. I said: What kind of prohibition is it that he (the Holy Prophet) has made? He said: We discussed it amongst -ourselves. Some of us aaid that it has been declared unlawful for ever, (whereas others said) it has been declared unlawful since one-fifth (of the booty) has not been given (to the treasury, as is legally required)}}
\hadithdefcmd{muslim}{5011}{وَحَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - حَدَّثَنَا سُلَيْمَانُ الشَّيْبَانِيُّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، يَقُولُ أَصَابَتْنَا مَجَاعَةٌ لَيَالِيَ خَيْبَرَ فَلَمَّا كَانَ يَوْمُ خَيْبَرَ وَقَعْنَا فِي الْحُمُرِ الأَهْلِيَّةِ فَانْتَحَرْنَاهَا فَلَمَّا غَلَتْ بِهَا الْقُدُورُ نَادَى مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِ اكْفَئُوا الْقُدُورَ وَلاَ تَأْكُلُوا مِنْ لُحُومِ الْحُمُرِ شَيْئًا - قَالَ - فَقَالَ نَاسٌ إِنَّمَا نَهَى عَنْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لأَنَّهَا لَمْ تُخَمَّسْ ‏.‏ وَقَالَ آخَرُونَ نَهَى عَنْهَا أَلْبَتَّةَ ‏.‏\hadithno{5011}\hadithtrans{Sulaiman Shaibini reported:I heard Abdullah b. Abu Aufa say: We were smitten with hunger during the nights of Khaibar. On the Day of Khaibar, we fell upon domestic asses and we slaughtered them, and when our earthen pots boiled with them, the announcer of Allah's Messenger (ﷺ) made an annoancement that the earthen pots should be turned over, and nothing should be eaten of the flesh of the domestic asses. Some of the people said that Allah's Messenger (ﷺ) had forbidden (the use of this flesh) for one-fifth (due to the State) has not been paid, while others said: He prohibited it for ever}}
\hadithdefcmd{muslim}{5012}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، - وَهُوَ ابْنُ ثَابِتٍ - قَالَ سَمِعْتُ الْبَرَاءَ، وَعَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، يَقُولاَنِ أَصَبْنَا حُمُرًا فَطَبَخْنَاهَا فَنَادَى مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم اكْفَئُوا الْقُدُورَ ‏.‏\hadithno{5012}\hadithtrans{Adi (he was the son of Thabit) said:I heard al-Bara' and 'Abdullah b. Abu Aufa say: We found domestic asses and we cooked them. Then the announcer of Allah's Messenger (ﷺ) made an announcement that the earthen pots should be turned over}}
\hadithdefcmd{muslim}{5013}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ قَالَ الْبَرَاءُ أَصَبْنَا يَوْمَ خَيْبَرَ حُمُرًا فَنَادَى مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِ اكْفَئُوا الْقُدُورَ ‏.‏\hadithno{5013}\hadithtrans{Al-Bara' said:We found on the Day of Khaibar domestic asses, and the announcer of the Messenger of Allah (ﷺ) made an announcement that the earthen pots should be turned over}}
\hadithdefcmd{muslim}{5014}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَبُو كُرَيْبٍ حَدَّثَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ نُهِينَا عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ، ‏.‏\hadithno{5014}\hadithtrans{Bara was heard saying:We were forbidden (to eat) the flesh of the domestic asses}}
\hadithdefcmd{muslim}{5015}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُلْقِيَ لُحُومَ الْحُمُرِ الأَهْلِيَّةِ نِيئَةً وَنَضِيجَةً ثُمَّ لَمْ يَأْمُرْنَا بِأَكْلِهِ ‏.‏\hadithno{5015}\hadithtrans{Bara' b. 'Azib reported:Allah's Messenger (ﷺ) commanded us to throw away the flesh of domestic asses whether uncooked or cooked; he then never commanded us to eat that}}
\hadithdefcmd{muslim}{5016}{وَحَدَّثَنِيهِ أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - عَنْ عَاصِمٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{5016}\hadithtrans{This hadith has been narrated on the authority of 'Asim with the same chain of transmitters}}
\hadithdefcmd{muslim}{5017}{وَحَدَّثَنِي أَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، عَنْ عَاصِمٍ، عَنْ عَامِرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لاَ أَدْرِي إِنَّمَا نَهَى عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ أَجْلِ أَنَّهُ كَانَ حَمُولَةَ النَّاسِ فَكَرِهَ أَنْ تَذْهَبَ حَمُولَتُهُمْ أَوْ حَرَّمَهُ فِي يَوْمِ خَيْبَرَ لُحُومَ الْحُمُرِ الأَهْلِيَّةِ ‏.‏\hadithno{5017}\hadithtrans{Ibn 'Abbas reported:I do not know whether Allah's Messenger (ﷺ) prohibited (the eating of the domestic ass) due to the fact that they were the beasts of burden for the people, so he (the Holy Prophet) did not like their beasts of burden to be destroyed (as a matter of expediency), or he prohibited the use of the flesh of domestic asses (not as an expediency but as a law of the Shari'ah) on the Day of Khaibar}}
\hadithdefcmd{muslim}{5018}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا حَاتِمٌ، - وَهُوَ ابْنُ إِسْمَاعِيلَ - عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى خَيْبَرَ ثُمَّ إِنَّ اللَّهَ فَتَحَهَا عَلَيْهِمْ فَلَمَّا أَمْسَى النَّاسُ الْيَوْمَ الَّذِي فُتِحَتْ عَلَيْهِمْ أَوْقَدُوا نِيرَانًا كَثِيرَةً فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا هَذِهِ النِّيرَانُ عَلَى أَىِّ شَىْءٍ تُوقِدُونَ ‏"‏ قَالُوا عَلَى لَحْمٍ ‏.‏ قَالَ ‏"‏ عَلَى أَىِّ لَحْمٍ ‏"‏ ‏.‏ قَالُوا عَلَى لَحْمِ حُمُرٍ إِنْسِيَّةٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَهْرِيقُوهَا وَاكْسِرُوهَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَوْ نُهَرِيقُهَا وَنَغْسِلُهَا قَالَ ‏"‏ أَوْ ذَاكَ ‏"‏ ‏.‏\hadithno{5018}\hadithtrans{Salama b. Akwa' reported:We went to Khaibar with Allah's Messenger (ﷺ). Then Allah granted (us) victory over them. On that very evening of the day when they had been granted victory, they lit many fires. Thereupon Allah's Messenger (ﷺ) said: What are those fires and what for those have been lit? They said: (These have been lit) for (cooking) the flesh. Thereupon he said: Of what flesh? They said: For the flesh of the domestic asses. Thereupon Allah's Messenger (may peace bo upon him) said: Throw that away and break them (the earthen pots in which the fiesa was being cooked). A person said: Messenger of Allah, should we throw it away and wash them (the cooking pots)? He said: You may do so}}
\hadithdefcmd{muslim}{5019}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا حَمَّادُ بْنُ مَسْعَدَةَ، وَصَفْوَانُ بْنُ عِيسَى، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ النَّضْرِ، حَدَّثَنَا أَبُو عَاصِمٍ النَّبِيلُ، كُلُّهُمْ عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5019}\hadithtrans{This hadith has been transmitted on the authority of Yazid b. Abu Ubaid}}
\hadithdefcmd{muslim}{5020}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، قَالَ لَمَّا فَتَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ أَصَبْنَا حُمُرًا خَارِجًا مِنَ الْقَرْيَةِ فَطَبَخْنَا مِنْهَا فَنَادَى مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم أَلاَ إِنَّ اللَّهَ وَرَسُولَهُ يَنْهَيَانِكُمْ عَنْهَا فَإِنَّهَا رِجْسٌ مِنْ عَمَلِ الشَّيْطَانِ ‏.‏ فَأُكْفِئَتِ الْقُدُورُ بِمَا فِيهَا وَإِنَّهَا لَتَفُورُ بِمَا فِيهَا ‏.‏\hadithno{5020}\hadithtrans{Anas reported:When Allah's Messenger (ﷺ) conquered Khaibar, we caught hold of the asses outside the village. We cooked them (their flesh). Then the announcer of Allah's Messenger (ﷺ) made the announcement: Listen, verily Allah and His Messenger have prohibited you (the eating of) their (flesh), for it is a loathsome evil of Satan's doing. Then the earthen pots were turned over along with what was in them, and these were brimming (with flesh) at that time}}
\hadithdefcmd{muslim}{5021}{حَدَّثَنَا مُحَمَّدُ بْنُ مِنْهَالٍ الضَّرِيرُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا كَانَ يَوْمُ خَيْبَرَ جَاءَ جَاءٍ فَقَالَ يَا رَسُولَ اللَّهِ أُكِلَتِ الْحُمُرُ ‏.‏ ثُمَّ جَاءَ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ أُفْنِيَتِ الْحُمُرُ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا طَلْحَةَ فَنَادَى إِنَّ اللَّهَ وَرَسُولَهُ يَنْهَيَانِكُمْ عَنْ لُحُومِ الْحُمُرِ فَإِنَّهَا رِجْسٌ أَوْ نَجِسٌ ‏.‏ قَالَ فَأُكْفِئَتِ الْقُدُورُ بِمَا فِيهَا ‏.‏\hadithno{5021}\hadithtrans{Anas b. Malik reported:When it was the Day of Khaibar a visitor came and said: Messenger of Allah, the asses have been eaten. Then another came and said: Messenger of Allah, the asses are being destroyed. Then Allah's Messenger (ﷺ) commanded Abu Talha to make an announcement that Allah and His Messenger have prohibited you (from eating) of the flesh of (domestic) asses, for these are loathsome or impure. He (the narrator) said: The earthein pots were turned over along with what was in them}}
\hadithdefcmd{muslim}{5022}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو الرَّبِيعِ الْعَتَكِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ مُحَمَّدِ، بْنِ عَلِيٍّ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى يَوْمَ خَيْبَرَ عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ وَأَذِنَ فِي لُحُومِ الْخَيْلِ ‏.‏\hadithno{5022}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Messenger (ﷺ) prohibited eating of the flesh of domestic asses on the Day of Khaibar, and permitted the cooking of the flesh of horses}}
\hadithdefcmd{muslim}{5023}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَكَلْنَا زَمَنَ خَيْبَرَ الْخَيْلَ وَحُمُرَ الْوَحْشِ وَنَهَانَا النَّبِيُّ صلى الله عليه وسلم عَنِ الْحِمَارِ الأَهْلِيِّ ‏.‏\hadithno{5023}\hadithtrans{Jabir b. 'Abdullah is reported to have said:We ate during the time of Khaibar the (flesh) of horses and of wild asses, but Allah's Messenger (ﷺ) prohibited us (to eat) the flesh of domestic asses}}
\hadithdefcmd{muslim}{5024}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، ح وَحَدَّثَنِي يَعْقُوبُ الدَّوْرَقِيُّ، وَأَحْمَدُ بْنُ، عُثْمَانَ النَّوْفَلِيُّ قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، كِلاَهُمَا عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5024}\hadithtrans{This hadith has hen transmitted on the authority of Ibn Juraij}}
\hadithdefcmd{muslim}{5025}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَحَفْصُ بْنُ غِيَاثٍ، وَوَكِيعٌ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ نَحَرْنَا فَرَسًا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَكَلْنَاهُ ‏.‏\hadithno{5025}\hadithtrans{Asma' reported:We slaughtered a horse and ate it during the lifetime of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{5026}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ كِلاَهُمَا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5026}\hadithtrans{This hadith has been transmitted on the authority of Hisham}}
\hadithdefcmd{muslim}{5027}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ عَنْ إِسْمَاعِيلَ، قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، يَقُولُ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الضَّبِّ فَقَالَ ‏ "‏ لَسْتُ بِآكِلِهِ وَلاَ مُحَرِّمِهِ ‏"‏ ‏.‏\hadithno{5027}\hadithtrans{Ibn 'Umar reported:Allah's Messenger (ﷺ) was asked about the eating of (the flesh) of the lizard, whereupon he said: I am neither the eater of it nor its prohibitor}}
\hadithdefcmd{muslim}{5028}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَأَلَ رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ الضَّبِّ فَقَالَ ‏ "‏ لاَ آكُلُهُ وَلاَ أُحَرِّمُهُ ‏"‏ ‏.‏\hadithno{5028}\hadithtrans{Ibn 'Umar reported:A person asked Allah's Messenger (ﷺ) about the eating of the lizard, whereupon he said. I neither eat it, nor do I prohibit it}}
\hadithdefcmd{muslim}{5029}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَأَلَ رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ عَنْ أَكْلِ الضَّبِّ فَقَالَ ‏ "‏ لاَ آكُلُهُ وَلاَ أُحَرِّمُهُ ‏"‏ ‏.‏\hadithno{5029}\hadithtrans{Ibn 'Umar reported that a person asked Allah's Messenger (ﷺ) as he was sitting on the pulpit about the eating of the lizard, whereupon he said:I neither eat it, nor do I prohibit it}}
\hadithdefcmd{muslim}{5030}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، بِمِثْلِهِ فِي هَذَا الإِسْنَادِ ‏.‏\hadithno{5030}\hadithtrans{This hadith has been narrated on the authority of 'Ubaidullah with the same chain of transmitters}}
\hadithdefcmd{muslim}{5031}{وَحَدَّثَنَاهُ أَبُو الرَّبِيعِ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، كِلاَهُمَا عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، ح وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ، اللَّهِ حَدَّثَنَا شُجَاعُ بْنُ الْوَلِيدِ، قَالَ سَمِعْتُ مُوسَى بْنَ عُقْبَةَ، ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ، الأَيْلِيُّ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ، كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الضَّبِّ بِمَعْنَى حَدِيثِ اللَّيْثِ عَنْ نَافِعٍ غَيْرَ أَنَّ حَدِيثَ أَيُّوبَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِضَبٍّ فَلَمْ يَأْكُلْهُ وَلَمْ يُحَرِّمْهُ وَفِي حَدِيثِ أُسَامَةَ قَالَ قَامَ رَجُلٌ فِي الْمَسْجِدِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ ‏.‏\hadithno{5031}\hadithtrans{A hadith pertaining to the eating of the lizard is transmitted from the Prophet (ﷺ) on the authority of Ibn 'Umar, but in this very hadith narrated through a different chain of transmitters there is a slight variation of wording (and the words are):" A lizard was brought to Allah's Messenger (ﷺ) but he neither ate that nor declared it unlawful." And in the hadith transmitted through Usama (the words are):" The man (inquirer) was standing in the mosque and Allah's Messenger (ﷺ) was sitting on the pulpit}}
\hadithdefcmd{muslim}{5032}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ تَوْبَةَ الْعَنْبَرِيِّ، سَمِعَ الشَّعْبِيَّ، سَمِعَ ابْنَ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ مَعَهُ نَاسٌ مِنْ أَصْحَابِهِ فِيهِمْ سَعْدٌ وَأُتُوا بِلَحْمِ ضَبٍّ فَنَادَتِ امْرَأَةٌ مِنْ نِسَاءِ النَّبِيِّ صلى الله عليه وسلم إِنَّهُ لَحْمُ ضَبٍّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُوا فَإِنَّهُ حَلاَلٌ وَلَكِنَّهُ لَيْسَ مِنْ طَعَامِي ‏"‏ ‏.‏\hadithno{5032}\hadithtrans{Ibn 'Umar reported that there were some persons with Allah's Apostle (ﷺ) from among his Companions, Sa'd being one of them. There was brought to them the flesh of the lizard when a lady amongst the wives of Allah's Apostle (ﷺ) said:It is the flesh of the lizard. Thereupon Allah's Messenger (way peace be upon him) said: Eat, for it is lawful, but it is not my diet}}
\hadithdefcmd{muslim}{5033}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ تَوْبَةَ الْعَنْبَرِيِّ، قَالَ قَالَ لِي الشَّعْبِيُّ أَرَأَيْتَ حَدِيثَ الْحَسَنِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَاعَدْتُ ابْنَ عُمَرَ قَرِيبًا مِنْ سَنَتَيْنِ أَوْ سَنَةٍ وَنِصْفٍ فَلَمْ أَسْمَعْهُ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ هَذَا قَالَ كَانَ نَاسٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فِيهِمْ سَعْدٌ بِمِثْلِ حَدِيثِ مُعَاذٍ ‏.‏\hadithno{5033}\hadithtrans{Taubat Al-'Anbari reported:Al-Sha'bi (one of the narrators) asked me if I had heard the hadith transmitted on the authority of Hasan from the Prophet (ﷺ). He said: I sat in the company if Ibn 'Umar for two years or a year and a half but I did not hear narrated from Allah's Apostle (ﷺ) but this one (pertaining to the flesh of the lizard) as narrated by Mu'adh}}
\hadithdefcmd{muslim}{5034}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ، بْنِ سَهْلِ بْنِ حُنَيْفٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ دَخَلْتُ أَنَا وَخَالِدُ بْنُ الْوَلِيدِ، مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَيْتَ مَيْمُونَةَ فَأُتِيَ بِضَبٍّ مَحْنُوذٍ فَأَهْوَى إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ فَقَالَ بَعْضُ النِّسْوَةِ اللاَّتِي فِي بَيْتِ مَيْمُونَةَ أَخْبِرُوا رَسُولَ اللَّهِ صلى الله عليه وسلم بِمَا يُرِيدُ أَنْ يَأْكُلَ ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ فَقُلْتُ أَحَرَامٌ هُوَ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ لاَ وَلَكِنَّهُ لَمْ يَكُنْ بِأَرْضِ قَوْمِي فَأَجِدُنِي أَعَافُهُ ‏"‏ ‏.‏ قَالَ خَالِدٌ فَاجْتَرَرْتُهُ فَأَكَلْتُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَنْظُرُ ‏.‏\hadithno{5034}\hadithtrans{Abdullah b. 'Abbas reported:I and Khalid b. Walid went to the apartment of Maimuna along with Allah's Messenger (ﷺ), and there was presented to him a roasted lizard. Allah's Messenger (ﷺ) stretched his hand towards It, whereupon some of the women who had been in the house of Maimuna said: Inform Allah's Messenger (ﷺ) what he intends to eat. Allah's Messenger (ﷺ) lifted his hand. I said: Messenger of Allah, Is it forbidden? He said: No. It is not found in the land of my people, and I feel that I have no liking for it. Khalid said: I then chewed and ate it, while, Allah's Messenger (ﷺ) was looking (at me)}}
\hadithdefcmd{muslim}{5035}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، جَمِيعًا عَنِ ابْنِ وَهْبٍ، قَالَ حَرْمَلَةُ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ الأَنْصَارِيِّ، أَنَّ عَبْدَ اللَّهِ، بْنَ عَبَّاسٍ أَخْبَرَهُ أَنَّ خَالِدَ بْنَ الْوَلِيدِ الَّذِي يُقَالُ لَهُ سَيْفُ اللَّهِ أَخْبَرَهُ أَنَّهُ، دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَهِيَ خَالَتُهُ وَخَالَةُ ابْنِ عَبَّاسٍ فَوَجَدَ عِنْدَهَا ضَبًّا مَحْنُوذًا قَدِمَتْ بِهِ أُخْتُهَا حُفَيْدَةُ بِنْتُ الْحَارِثِ مِنْ نَجْدٍ فَقَدَّمَتِ الضَّبَّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ قَلَّمَا يُقَدَّمُ إِلَيْهِ طَعَامٌ حَتَّى يُحَدَّثَ بِهِ وَيُسَمَّى لَهُ فَأَهْوَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ إِلَى الضَّبِّ فَقَالَتِ امْرَأَةٌ مِنَ النِّسْوَةِ الْحُضُورِ أَخْبِرْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم بِمَا قَدَّمْتُنَّ لَهُ ‏.‏ قُلْنَ هُوَ الضَّبُّ يَا رَسُولَ اللَّهِ ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ فَقَالَ خَالِدُ بْنُ الْوَلِيدِ أَحَرَامٌ الضَّبُّ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ لاَ وَلَكِنَّهُ لَمْ يَكُنْ بِأَرْضِ قَوْمِي فَأَجِدُنِي أَعَافُهُ ‏"‏ ‏.‏ قَالَ خَالِدٌ فَاجْتَرَرْتُهُ فَأَكَلْتُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَنْظُرُ فَلَمْ يَنْهَنِي ‏.‏\hadithno{5035}\hadithtrans{Abdullah b. 'Abbas reported that Khalid b. Walid who is called the Sword of Allah had informed him that he visited Maimuna, the wife of Allah's Apostle (ﷺ), in the company of Allah's Messenger (ﷺ), and she was the sister of his mother (that of Khalid) and that of 'Ibn Abbas, and he found with her a roasted lizard which her sister Hufaida the daughter of al-Harith had brought from Najd, and she presented that lizard to Allah's Messenger (ﷺ). It was rare that some food was presented to the Prophet (ﷺ) and it was not mentioned or named. While Allah's Messenger (ﷺ) was about to stretch forth his hand towards the lizard, a woman from amongst the women present there informed the Messenger of Allah (ﷺ) what they had presented to him. They said:Messenger of Allah, it is a lizard. Allah's Messenger (ﷺ) withdrew his hand, whereupon Khalid b. Walid said: Messenger of Allah, is a lizard forbidden? There opon he said: No, but it is not found in the land of my people, and I feel that I have no liking for it. Khalid said: I then chewed and ate it, and Allah's Messenger (ﷺ) was looking at me and he did not forbid (me to eat it)}}
\hadithdefcmd{muslim}{5036}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ النَّضْرِ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنِي وَقَالَ أَبُو بَكْرٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي، أُمَامَةَ بْنِ سَهْلٍ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ أَخْبَرَهُ أَنَّ خَالِدَ بْنَ الْوَلِيدِ أَخْبَرَهُ أَنَّهُ، دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى مَيْمُونَةَ بِنْتِ الْحَارِثِ وَهْىَ خَالَتُهُ فَقُدِّمَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَحْمُ ضَبٍّ جَاءَتْ بِهِ أُمُّ حُفَيْدٍ بِنْتُ الْحَارِثِ مِنْ نَجْدٍ وَكَانَتْ تَحْتَ رَجُلٍ مِنْ بَنِي جَعْفَرٍ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَأْكُلُ شَيْئًا حَتَّى يَعْلَمَ مَا هُوَ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ يُونُسَ وَزَادَ فِي آخِرِ الْحَدِيثِ وَحَدَّثَهُ ابْنُ الأَصَمِّ عَنْ مَيْمُونَةَ وَكَانَ فِي حَجْرِهَا ‏.‏\hadithno{5036}\hadithtrans{Khalid b. Walid reported that he visited Maimuna daughter of al-Harith with the Messenger of Allah (ﷺ), and she was the sister of his mother. She presented to Allah's Messenger (ﷺ) the flesh of a lizard which Umm Hufaid daughter of al-Harith had brought from Najd, and she had been married to a person belonging to Banu Ja'far. It was the habit of Allah's Messenger (ﷺ) not to eat anything until he knew what that was. The rest of the hadith is the same but with this (addition):" Ibn al-Asamm narrated it from Maimuna and he was under her care}}
\hadithdefcmd{muslim}{5037}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي، أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم وَنَحْنُ فِي بَيْتِ مَيْمُونَةَ بِضَبَّيْنِ مَشْوِيَّيْنِ ‏.‏ بِمِثْلِ حَدِيثِهِمْ وَلَمْ يَذْكُرْ يَزِيدَ بْنَ الأَصَمِّ عَنْ مَيْمُونَةَ ‏.‏\hadithno{5037}\hadithtrans{Ibn 'Abbas reported:While we were in the house of Maimuna there were brought to Allah's Messenger two roasted lizards. Here no mention is made of al- 'Asamm narrating from Maimuna}}
\hadithdefcmd{muslim}{5038}{وَحَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنَا أَبِي، عَنْ جَدِّي، حَدَّثَنِي خَالِدُ بْنُ، يَزِيدَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي هِلاَلٍ، عَنِ ابْنِ الْمُنْكَدِرِ، أَنَّ أَبَا أُمَامَةَ بْنَ سَهْلٍ، أَخْبَرَهُ عَنِ ابْنِ، عَبَّاسٍ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي بَيْتِ مَيْمُونَةَ وَعِنْدَهُ خَالِدُ بْنُ الْوَلِيدِ بِلَحْمِ ضَبٍّ ‏.‏ فَذَكَرَ بِمَعْنَى حَدِيثِ الزُّهْرِيِّ ‏.‏\hadithno{5038}\hadithtrans{Ibn 'Abbas reported that there had been brought to Allah's Messenger (ﷺ) the flesh of a lizard and Khalid b. Walid was also present there. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5039}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو بَكْرِ بْنُ نَافِعٍ قَالَ ابْنُ نَافِعٍ أَخْبَرَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَهْدَتْ خَالَتِي أُمُّ حُفَيْدٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سَمْنًا وَأَقِطًا وَأَضُبًّا فَأَكَلَ مِنَ السَّمْنِ وَالأَقِطِ وَتَرَكَ الضَّبَّ تَقَذُّرًا وَأُكِلَ عَلَى مَائِدَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَوْ كَانَ حَرَامًا مَا أُكِلَ عَلَى مَائِدَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5039}\hadithtrans{Sa'id b. Jubair reported that he heard Ibn 'Abbas says:The sister of my mother Umm Hufaid presented to Allah's Messenger (ﷺ) clarified butter (ghee), cheese and some lizards. He ate out of the clarified butter and cheese, but left the lizard finding no liking for it. But it was eaten on the table of Allah's Messenger (ﷺ). Had it been forbidden (haram), it could not be eaten on the table of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{5040}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، عَنْ يَزِيدَ بْنِ، الأَصَمِّ قَالَ دَعَانَا عَرُوسٌ بِالْمَدِينَةِ فَقَرَّبَ إِلَيْنَا ثَلاَثَةَ عَشَرَ ضَبًّا فَآكِلٌ وَتَارِكٌ فَلَقِيتُ ابْنَ عَبَّاسٍ مِنَ الْغَدِ فَأَخْبَرْتُهُ فَأَكْثَرَ الْقَوْمُ حَوْلَهُ حَتَّى قَالَ بَعْضُهُمْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ آكُلُهُ وَلاَ أَنْهَى عَنْهُ وَلاَ أُحَرِّمُهُ ‏"‏ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ بِئْسَ مَا قُلْتُمْ مَا بُعِثَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِلاَّ مُحِلاًّ وَمُحَرِّمًا إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَيْنَمَا هُوَ عِنْدَ مَيْمُونَةَ وَعِنْدَهُ الْفَضْلُ بْنُ عَبَّاسٍ وَخَالِدُ بْنُ الْوَلِيدِ وَامْرَأَةٌ أُخْرَى إِذْ قُرِّبَ إِلَيْهِمْ خِوَانٌ عَلَيْهِ لَحْمٌ فَلَمَّا أَرَادَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَأْكُلَ قَالَتْ لَهُ مَيْمُونَةُ إِنَّهُ لَحْمُ ضَبٍّ ‏.‏ فَكَفَّ يَدَهُ وَقَالَ ‏"‏ هَذَا لَحْمٌ لَمْ آكُلْهُ قَطُّ ‏"‏ ‏.‏ وَقَالَ لَهُمْ ‏"‏ كُلُوا ‏"‏ ‏.‏ فَأَكَلَ مِنْهُ الْفَضْلُ وَخَالِدُ بْنُ الْوَلِيدِ وَالْمَرْأَةُ ‏.‏ وَقَالَتْ مَيْمُونَةُ لاَ آكُلُ مِنْ شَىْءٍ إِلاَّ شَىْءٌ يَأْكُلُ مِنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5040}\hadithtrans{Yazid b. al-Asamm reported:A newly wedded person of Medina invited us to a wedding feast, and he served us thirteen lizards. There were those who ate it and those who abandoned it. I met Ibn 'Abbas the next day, and informed him (about this) in the presence of many persons. Some of them said that the Messenger of Allah (ﷺ) had observed: I neither eat it nor forbid (anyone) from eating it, nor declare it to be unlawful. Thereupon Ibn 'Abbas said: Sad it is what you say! Allah's Apostle (ﷺ) has not been sent, but (to declare in clear words) the lawful and the unlawful (things). We were once with Allah's Messenger (may peace be. upon him) as he was with Maimuna, and there were with him al-Fadl b. 'Abbas, Khalid b. Walid and some women (also) when a tray of food containing flesh was presented to him. As Allah's Apostle (ﷺ) was about to eat that, Maimuna said: It is the flesh of the lizard. He withdrew his hand saying: That is the flesh which I never eat; but he said to them (those who were present there): You may eat. Al-Fadl ate out of that, so did Khalid b Walid, and the women. Maimuna (however) said: I do not eat anything but that which Allah's Messenger (ﷺ) eats}}
\hadithdefcmd{muslim}{5041}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ، جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِضَبٍّ فَأَبَى أَنْ يَأْكُلَ مِنْهُ وَقَالَ ‏ "‏ لاَ أَدْرِي لَعَلَّهُ مِنَ الْقُرُونِ الَّتِي مُسِخَتْ ‏"‏ ‏.‏\hadithno{5041}\hadithtrans{Abu Zubair reported that he heard Jabir b. 'Abdullah saying that there was presented to Allah's Messenger (the flesh) of the lizard, but he refused to eat that, saying:I do not know; perhaps it (lizard) might (be one of those natives of) the distant past whose (forms) had beer, distorted}}
\hadithdefcmd{muslim}{5042}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، قَالَ سَأَلْتُ جَابِرًا عَنِ الضَّبِّ، فَقَالَ لاَ تَطْعَمُوهُ ‏.‏ وَقَذِرَهُ وَقَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ إِنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يُحَرِّمْهُ ‏.‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَنْفَعُ بِهِ غَيْرَ وَاحِدٍ فَإِنَّمَا طَعَامُ عَامَّةِ الرِّعَاءِ مِنْهُ وَلَوْ كَانَ عِنْدِي طَعِمْتُهُ ‏.‏\hadithno{5042}\hadithtrans{(Abu Zubair reported:I asked Jabir about ithe eating) of the lizard, whereupon he said: Don't eat that as he (the Holy Prophet) felt disgust. He (the narrator) said that Umar b. al-Khattab reminded: Allah's Apostle (ﷺ) did not declare it to be unlawful. Allah, the Exalted and Majestic, has (made it a source) of benefit for more than one (persons). It is a common diet of the shepherds. Had it been with me, I would have eaten that}}
\hadithdefcmd{muslim}{5043}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ دَاوُدَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ إِنَّا بِأَرْضٍ مَضَبَّةٍ فَمَا تَأْمُرُنَا أَوْ فَمَا تُفْتِينَا قَالَ ‏ "‏ ذُكِرَ لِي أَنَّ أُمَّةً مِنْ بَنِي إِسْرَائِيلَ مُسِخَتْ ‏"‏ ‏.‏ فَلَمْ يَأْمُرْ وَلَمْ يَنْهَ ‏.‏ قَالَ أَبُو سَعِيدٍ فَلَمَّا كَانَ بَعْدَ ذَلِكَ قَالَ عُمَرُ إِنَّ اللَّهَ عَزَّ وَجَلَّ لَيَنْفَعُ بِهِ غَيْرَ وَاحِدٍ وَإِنَّهُ لَطَعَامُ عَامَّةِ هَذِهِ الرِّعَاءِ وَلَوْ كَانَ عِنْدِي لَطَعِمْتُهُ إِنَّمَا عَافَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5043}\hadithtrans{Abu Sa'id reported that a person said:Messenger of Allah, we live in a land abounding in lizards, so what do you command or what verdict you give (about eating of it)? Thereupon he said: It was mentioned to me that a people from among Bani Isra'il were distorted (so there is a likelihood that those people might have been distorted in the shape of lizards). So he neither commanded (us to eat that) nor forbade (us). Abu Sa'id said: After some time Umar said: Allah, the Exalted and Majestic, has made it (a source of) benefit for more than one (person), for it is the common diet of shepherds. Had it been with me, I would have eaten that. Allah's Messenger (ﷺ) disliked it}}
\hadithdefcmd{muslim}{5044}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا أَبُو عَقِيلٍ الدَّوْرَقِيُّ، حَدَّثَنَا أَبُو نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ أَعْرَابِيًّا، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي فِي غَائِطٍ مَضَبَّةٍ وَإِنَّهُ عَامَّةُ طَعَامِ أَهْلِي - قَالَ - فَلَمْ يُجِبْهُ فَقُلْنَا عَاوِدْهُ ‏.‏ فَعَاوَدَهُ فَلَمْ يُجِبْهُ ثَلاَثًا ثُمَّ نَادَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الثَّالِثَةِ فَقَالَ ‏ "‏ يَا أَعْرَابِيُّ إِنَّ اللَّهَ لَعَنَ أَوْ غَضِبَ عَلَى سِبْطٍ مِنْ بَنِي إِسْرَائِيلَ فَمَسَخَهُمْ دَوَابَّ يَدِبُّونَ فِي الأَرْضِ فَلاَ أَدْرِي لَعَلَّ هَذَا مِنْهَا فَلَسْتُ آكُلُهَا وَلاَ أَنْهَى عَنْهَا ‏"‏ ‏.‏\hadithno{5044}\hadithtrans{Abu Sa'id reported that an Arab of the desert came to Allah's Messenger (ﷺ) and said:I live in a low land abounding in lizards, and these are the common diet of my family, but he (the Holy Prophet) did not make any reply. We said to him: Repeat it (your problem) and so he repeated it, but he did not make any reply. (It was repeated thrice ) Then Allah's Messenger (ﷺ) called him out at the third time saying: O man of the desert, verily Allah cursed or showed wrath to a tribe of Bani Isra'il and distorted them to beasts which move on the earth. I do not know, perhaps this (lizard) may be one of them. So I do not eat it, nor do I prohibit the eating of it}}
\hadithdefcmd{muslim}{5045}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي يَعْفُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ، أَبِي أَوْفَى قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سَبْعَ غَزَوَاتٍ نَأْكُلُ الْجَرَادَ ‏.‏\hadithno{5045}\hadithtrans{Ibn Abu Aufa reported:We went on seven expeditions with Allah's Messenger (ﷺ) and ate locusts}}
\hadithdefcmd{muslim}{5046}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنْ أَبِي يَعْفُورٍ، بِهَذَا الإِسْنَادِ ‏.‏ قَالَ أَبُو بَكْرٍ فِي رِوَايَتِهِ سَبْعَ غَزَوَاتٍ وَقَالَ إِسْحَاقُ سِتَّ وَقَالَ ابْنُ أَبِي عُمَرَ سِتَّ أَوْ سَبْعَ ‏.‏\hadithno{5046}\hadithtrans{This hadith has been narrated on the authority of Abu Ya'fur with the same chain of transmitters. Abu Bakr (one of the narrators) said" seven expeditions," whereas Ishaq said" six," and Ibn Umar said" six" or" seven}}
\hadithdefcmd{muslim}{5047}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنَا ابْنُ بَشَّارٍ، عَنْ مُحَمَّدِ، بْنِ جَعْفَرٍ كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ أَبِي يَعْفُورٍ، بِهَذَا الإِسْنَادِ وَقَالَ سَبْعَ غَزَوَاتٍ ‏.‏\hadithno{5047}\hadithtrans{This hadith is narrated on the authority of Abu Ya'fur with the same chain of transmitters, and he mentioned seven expeditions}}
\hadithdefcmd{muslim}{5048}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَرَرْنَا فَاسْتَنْفَجْنَا أَرْنَبًا بِمَرِّ الظَّهْرَانِ فَسَعَوْا عَلَيْهِ فَلَغَبُوا ‏.‏ قَالَ فَسَعَيْتُ حَتَّى أَدْرَكْتُهَا فَأَتَيْتُ بِهَا أَبَا طَلْحَةَ فَذَبَحَهَا فَبَعَثَ بِوَرِكِهَا وَفَخِذَيْهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُ بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَبِلَهُ ‏.‏\hadithno{5048}\hadithtrans{Anas b. Malik reported:We chased a hare at Marr az-Zahrin (a valley near Mecca). They (my companions) ran, but felt exhausted; I also tried until I caught hold of it. I brought it to Abu Talha. He slaughtered it and sent its haunch and two hind legs to Allah's Messenger (ﷺ) through me; and he accepted them}}
\hadithdefcmd{muslim}{5049}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ يَحْيَى بِوَرِكِهَا أَوْ فَخِذَيْهَا ‏.‏\hadithno{5049}\hadithtrans{This hadith has been transmitted on the authority of Yahya with a slight change of wording}}
\hadithdefcmd{muslim}{5050}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا كَهْمَسٌ، عَنِ ابْنِ بُرَيْدَةَ، قَالَ رَأَى عَبْدُ اللَّهِ بْنُ الْمُغَفَّلِ رَجُلاً مِنْ أَصْحَابِهِ يَخْذِفُ فَقَالَ لَهُ لاَ تَخْذِفْ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَكْرَهُ - أَوْ قَالَ - يَنْهَى عَنِ الْخَذْفِ فَإِنَّهُ لاَ يُصْطَادُ بِهِ الصَّيْدُ وَلاَ يُنْكَأُ بِهِ الْعَدُوُّ وَلَكِنَّهُ يَكْسِرُ السِّنَّ وَيَفْقَأُ الْعَيْنَ ‏.‏ ثُمَّ رَآهُ بَعْدَ ذَلِكَ يَخْذِفُ فَقَالَ لَهُ أُخْبِرُكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَكْرَهُ أَوْ يَنْهَى عَنِ الْخَذْفِ ثُمَّ أَرَاكَ تَخْذِفُ لاَ أُكَلِّمُكَ كَلِمَةً كَذَا وَكَذَا ‏.‏\hadithno{5050}\hadithtrans{Ibn Buraida reported that Abdullah b. al-Mughaffal saw a person from amongst his companions throwing small pebbles, whereupon he said:Don't throw pebbles. for Allah's Messenger (ﷺ) did not like it, or he forbade flinging of pebbles since neither the game is taken thereby, nor an enemy defeated. but it may break a tooth or put out an eye. He, afterwards, again saw him flinging pebbles, and said to him: I inform you that the Messenger of Allah (ﷺ) did not approve or he forbade flinging of pebbles, but if I see you again flinging pebbles. I will not speak with you}}
\hadithdefcmd{muslim}{5051}{حَدَّثَنِي أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ مَعْبَدٍ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا كَهْمَسٌ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{5051}\hadithtrans{This hadith has been transmitted on the authority of Kahmas}}
\hadithdefcmd{muslim}{5052}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عُقْبَةَ بْنِ صُهْبَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْخَذْفِ ‏.‏ قَالَ ابْنُ جَعْفَرٍ فِي حَدِيثِهِ وَقَالَ إِنَّهُ لاَ يَنْكَأُ الْعَدُوَّ وَلاَ يَقْتُلُ الصَّيْدَ وَلَكِنَّهُ يَكْسِرُ السِّنَّ وَيَفْقَأُ الْعَيْنَ ‏.‏ وَقَالَ ابْنُ مَهْدِيٍّ إِنَّهَا لاَ تَنْكَأُ الْعَدُوَّ ‏.‏ وَلَمْ يَذْكُرْ تَفْقَأُ الْعَيْنَ ‏.‏\hadithno{5052}\hadithtrans{Abdullah b. Mughaffal reported that Allah's Messenger (ﷺ) prohibited throwing of pebbles. Ibn Ja'far reported (in the narration transmitted by him) that he (the Holy Prophet) said:It neither inflicts defeat to the enemy nor kills the game but breaks the tooth and puts the eye out. This hadith has been transmitted on the authority of Ibn Mahdi with a slight variation of wording}}
\hadithdefcmd{muslim}{5053}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ، بْنِ جُبَيْرٍ أَنَّ قَرِيبًا، لِعَبْدِ اللَّهِ بْنِ مُغَفَّلٍ خَذَفَ - قَالَ - فَنَهَاهُ وَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْخَذْفِ وَقَالَ ‏ "‏ إِنَّهَا لاَ تَصِيدُ صَيْدًا وَلاَ تَنْكَأُ عَدُوًّا وَلَكِنَّهَا تَكْسِرُ السِّنَّ وَتَفْقَأُ الْعَيْنَ ‏"‏ ‏.‏ قَالَ فَعَادَ ‏.‏ فَقَالَ أُحَدِّثُكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهُ ثُمَّ تَخْذِفُ لاَ أُكَلِّمُكَ أَبَدًا ‏.‏\hadithno{5053}\hadithtrans{Sa'id b. Jubair reported that. a near one of 'Abdullah b. Mughaffal threw pebbles. He prohibited him (to do so). He said that Allah's Messenger (ﷺ) had prohibited the throwing of pebbles by saying:It does not catch the game, nor does it inflict defeat on the enemy, but breaks the tooth and puts the eye out. He (the near one of Abdullah b. Mughadal) again repeated it (the act of throwing of pebbles) whereupon he said: I narrate to you that Allah's Messenger (may peace be upon hish) disliked and prohibited throwing of pebbles, but I see you again throwing pebbles; I (would therefore) not speak with you}}
\hadithdefcmd{muslim}{5054}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا الثَّقَفِيُّ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{5054}\hadithtrans{This hadith has been narrated on the authority of Ayyub with the same chain of transmitters}}
\hadithdefcmd{muslim}{5055}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ ثِنْتَانِ حَفِظْتُهُمَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ كَتَبَ الإِحْسَانَ عَلَى كُلِّ شَىْءٍ فَإِذَا قَتَلْتُمْ فَأَحْسِنُوا الْقِتْلَةَ وَإِذَا ذَبَحْتُمْ فَأَحْسِنُوا الذَّبْحَ وَلْيُحِدَّ أَحَدُكُمْ شَفْرَتَهُ فَلْيُرِحْ ذَبِيحَتَهُ ‏"‏ ‏.‏\hadithno{5055}\hadithtrans{Shaddid b. Aus said:Two are the things which I remember Allah's Messenger (ﷺ) having said: Verily Allah has enjoined goodness to everything; so when you kill, kill in a good way and when you slaughter, slaughter in a good way. So every one of you should sharpen his knife, and let the slaughtered animal die comfortably}}
\hadithdefcmd{muslim}{5056}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا هُشَيْمٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، كُلُّ هَؤُلاَءِ عَنْ خَالِدٍ الْحَذَّاءِ، بِإِسْنَادِ حَدِيثِ ابْنِ عُلَيَّةَ وَمَعْنَى حَدِيثِهِ ‏.‏\hadithno{5056}\hadithtrans{This hadith has been narrated on the authority of Khalid al-Hadhdha' through different chains o transmitters}}
\hadithdefcmd{muslim}{5057}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ هِشَامَ، بْنَ زَيْدِ بْنِ أَنَسِ بْنِ مَالِكٍ قَالَ دَخَلْتُ مَعَ جَدِّي أَنَسِ بْنِ مَالِكٍ دَارَ الْحَكَمِ بْنِ أَيُّوبَ فَإِذَا قَوْمٌ قَدْ نَصَبُوا دَجَاجَةً يَرْمُونَهَا قَالَ فَقَالَ أَنَسٌ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُصْبَرَ الْبَهَائِمُ ‏.‏\hadithno{5057}\hadithtrans{Hishim b. Zaid b. Anas b. Milik reported:I visited the house of al-Hakam b. Ayyub along with my grandfather Anas b. Milik, (and there) some people had made a hen a target and were shooting arrows at her. Thereupon Asas said that Allah's Messenger (ﷺ) had forbidden tying of the animals (and making them the targets of arrows, etc)}}
\hadithdefcmd{muslim}{5058}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، ح وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5058}\hadithtrans{This hadith has been narrated on the authority of Shu'ba through other chains of transmitters}}
\hadithdefcmd{muslim}{5059}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَتَّخِذُوا شَيْئًا فِيهِ الرُّوحُ غَرَضًا ‏"‏ ‏.‏\hadithno{5059}\hadithtrans{Ibn 'Abbas reported Allah's Messenger (ﷺ) having said this:Do not make anything having life as a target}}
\hadithdefcmd{muslim}{5060}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5060}\hadithtrans{This hadith has been narrated on the authority of Shu'ba through a different chain of transmitters}}
\hadithdefcmd{muslim}{5061}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، وَأَبُو كَامِلٍ - وَاللَّفْظُ لأَبِي كَامِلٍ - قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ مَرَّ ابْنُ عُمَرَ بِنَفَرٍ قَدْ نَصَبُوا دَجَاجَةً يَتَرَامَوْنَهَا فَلَمَّا رَأَوُا ابْنَ عُمَرَ تَفَرَّقُوا عَنْهَا ‏.‏ فَقَالَ ابْنُ عُمَرَ مَنْ فَعَلَ هَذَا إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ مَنْ فَعَلَ هَذَا ‏.‏\hadithno{5061}\hadithtrans{Sa'id b. Jubair reported that Ibn 'Umar happened to pass by a party of men who had tied a hen and were shooting arrows at it. As soon as they saw Ibn 'Umar, they scattered from it. Thereupon Ibn Umar said:Who has done this? Verily Allah's Messenger (ﷺ) has invoked curse upon him who does this}}
\hadithdefcmd{muslim}{5062}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ مَرَّ ابْنُ عُمَرَ بِفِتْيَانٍ مِنْ قُرَيْشٍ قَدْ نَصَبُوا طَيْرًا وَهُمْ يَرْمُونَهُ وَقَدْ جَعَلُوا لِصَاحِبِ الطَّيْرِ كُلَّ خَاطِئَةٍ مِنْ نَبْلِهِمْ فَلَمَّا رَأَوُا ابْنَ عُمَرَ تَفَرَّقُوا فَقَالَ ابْنُ عُمَرَ مَنْ فَعَلَ هَذَا لَعَنَ اللَّهُ مَنْ فَعَلَ هَذَا إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ مَنِ اتَّخَذَ شَيْئًا فِيهِ الرُّوحُ غَرَضًا ‏.‏\hadithno{5062}\hadithtrans{Sa'id b. Jubair reported that Ibn 'Umar happened to pass by some young men of the Quraish who had tied a bird (and th, is made it a target) at which they had been shooting arrows Every arrow that they missed came into the possession of the owner of the bird. So no sooner did they see Ibn 'Umar they went away. Thereupon Ibn 'Umar said:Who has done this? Allah has cursed him who does this. Verily Allah's Messenger (ﷺ) invoked curse upon one who made a live thing the target (of one's marksmanship)}}
\hadithdefcmd{muslim}{5063}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنَا عَبْدُ، بْنُ حُمَيْدٍ أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُقْتَلَ شَىْءٌ مِنَ الدَّوَابِّ صَبْرًا ‏.‏\hadithno{5063}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Messenger (ﷺ) forbade that any beast should be killed after it has been tied}}
